==> news-feed-1.5.0-20140319.184450-1-sources.jar: org/gcube/portlets/user/newsfeed/client/NewsServiceAsync.java <==
package org.gcube.portlets.user.newsfeed.client;

import java.util.ArrayList;

import org.gcube.portal.databook.shared.Comment;
import org.gcube.portal.databook.shared.Like;
import org.gcube.portlets.user.newsfeed.shared.EnhancedFeed;
import org.gcube.portlets.user.newsfeed.shared.UserSettings;

import com.google.gwt.user.client.rpc.AsyncCallback;

/**
 * The async counterpart of <code>NewsService</code>.
 */
public interface NewsServiceAsync {

	void getAllUpdateUserFeeds(int feedsNoPerCategory,
			AsyncCallback<ArrayList<EnhancedFeed>> callback);

	void getOnlyConnectionsUserFeeds(
			AsyncCallback<ArrayList<EnhancedFeed>> callback);

	void like(String feedid, String feedText, String feedOwnerId,
			AsyncCallback<Boolean> callback);

	void getAllLikesByFeed(String feedid,
			AsyncCallback<ArrayList<Like>> callback);

	void getOnlyMyUserFeeds(AsyncCallback<ArrayList<EnhancedFeed>> callback);

	void getUserSettings(AsyncCallback<UserSettings> callback);

	void comment(String feedid, String text, String feedOwnerId,
			boolean isAppFeed, AsyncCallback<Comment> callback);

	void getAllCommentsByFeed(String feedid,
			AsyncCallback<ArrayList<Comment>> callback);

	void deleteComment(String commentid, String feedid,
			AsyncCallback<Boolean> callback);

	void deleteFeed(String feedid, AsyncCallback<Boolean> callback);

	void editComment(Comment toEdit, AsyncCallback<Comment> callback);

	void getOnlyLikedFeeds(AsyncCallback<ArrayList<EnhancedFeed>> callback);

	void getSingleFeed(String feedKey, AsyncCallback<EnhancedFeed> callback);
	
}

==> news-feed-1.6.0-20140328.220409-5-sources.jar: org/gcube/portlets/user/newsfeed/client/NewsServiceAsync.java <==
package org.gcube.portlets.user.newsfeed.client;

import java.util.ArrayList;

import org.gcube.portal.databook.shared.Comment;
import org.gcube.portal.databook.shared.Like;
import org.gcube.portlets.user.newsfeed.shared.EnhancedFeed;
import org.gcube.portlets.user.newsfeed.shared.MoreFeedsBean;
import org.gcube.portlets.user.newsfeed.shared.UserSettings;

import com.google.gwt.user.client.rpc.AsyncCallback;

/**
 * The async counterpart of <code>NewsService</code>.
 */
public interface NewsServiceAsync {

	void getAllUpdateUserFeeds(int feedsNoPerCategory,
			AsyncCallback<ArrayList<EnhancedFeed>> callback);

	void getOnlyConnectionsUserFeeds(
			AsyncCallback<ArrayList<EnhancedFeed>> callback);

	void like(String feedid, String feedText, String feedOwnerId,
			AsyncCallback<Boolean> callback);

	void getAllLikesByFeed(String feedid,
			AsyncCallback<ArrayList<Like>> callback);

	void getOnlyMyUserFeeds(AsyncCallback<ArrayList<EnhancedFeed>> callback);

	void getUserSettings(AsyncCallback<UserSettings> callback);

	void comment(String feedid, String text, String feedOwnerId,
			boolean isAppFeed, AsyncCallback<Comment> callback);

	void getAllCommentsByFeed(String feedid,
			AsyncCallback<ArrayList<Comment>> callback);

	void deleteComment(String commentid, String feedid,
			AsyncCallback<Boolean> callback);

	void deleteFeed(String feedid, AsyncCallback<Boolean> callback);

	void editComment(Comment toEdit, AsyncCallback<Comment> callback);

	void getOnlyLikedFeeds(AsyncCallback<ArrayList<EnhancedFeed>> callback);

	void getSingleFeed(String feedKey, AsyncCallback<EnhancedFeed> callback);

	void getMoreFeeds(int from, int quantity,
			AsyncCallback<MoreFeedsBean> callback);
	
}
